# -*- coding: utf-8 -*-
"""
Copyright 2014 Mariano D'Agostino

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import math
from pylares import utilidades


def DesdeHasta(desde, hasta, incremento = 1):

    utilidades._ValidarParametro(desde, "desde", (int))
    utilidades._ValidarParametro(hasta, "hasta", (int))
    utilidades._ValidarParametro(incremento, "incremento", (int))

    if desde > hasta:
        if incremento > 0:
            incremento = incremento * -1
        return list(range(desde, hasta - 1, incremento))
    else:
        if incremento < 0:
            incremento = incremento * -1

    return list(range(desde, hasta + 1, incremento))



def Aleatorio(minimo, maximo):
    import random
    if isinstance(minimo, float) or isinstance(maximo, float):
        return minimo + random.random() * (maximo - minimo)
    else:
        return random.randrange(minimo, maximo + 1)


def ValorAbsoluto(numero):
    if isinstance(numero, int):
        return abs(numero)
    else:
        return math.fabs(numero)


def RaizCuadrada(numero):
    return math.sqrt(numero)


def Redondear(numero, decimales):
    return round(numero, decimales)
